==> haskell-vault-0.3.0.6-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vault/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.6
id: vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
key: vault_6a139yu66oWGEEnx8egA4x
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.6
hs-libraries: HSvault-0.3.0.6-6a139yu66oWGEEnx8egA4x
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.0.6-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-vault/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.0.6
id: vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
key: vault_Ds02DFWDupK8kyaJ6uM5fA
license: BSD3
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules:
    Data.Vault.Lazy Data.Vault.Strict Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Unique.Really
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/vault-0.3.0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/vault-0.3.0.6
hs-libraries: HSvault-0.3.0.6-Ds02DFWDupK8kyaJ6uM5fA
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
